Legacy client — python-copr 1.63 documentation

# Legacy client

Warning

Legacy client is obsolete, please use Client version 3 instead. This document describes the migration process.

All interaction are done through copr.CoprClient. It can be created directly or using config file `/etc/copr.conf`

CoprClient offers methods that directly reflect Copr api. Received data are wrapped into the Response object. Depending on used methods Responses will have different set of provided attributes and methods.

- Create client
- Get projects list
- Search for projects
- Create/update/delete project
- Work with builds

See method signatures and response objects in the auto generated documentation:

- CoprClient
- Responses
- Data wrappers